#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arrows
version:              0.4.4.2
visibility:           public
id:                   arrows-0.4.4.2-J5DN5SZKXaXIf3BUZgn1I0
key:                  arrows-0.4.4.2-J5DN5SZKXaXIf3BUZgn1I0
license:              BSD-3-Clause
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
author:               Ross Paterson <R.Paterson@city.ac.uk>
homepage:             http://www.haskell.org/arrows/
synopsis:             Arrow classes and transformers
description:
    Several classes that extend the Arrow class, and some
    transformers that implement or lift these classes.

category:             Control
abi:                  273c69195793c8575e188743e2a6cd75
exposed:              True
exposed-modules:
    Control.Arrow.Operations Control.Arrow.Transformer
    Control.Arrow.Transformer.All Control.Arrow.Transformer.Automaton
    Control.Arrow.Transformer.CoState Control.Arrow.Transformer.Error
    Control.Arrow.Transformer.Reader Control.Arrow.Transformer.State
    Control.Arrow.Transformer.Static Control.Arrow.Transformer.Stream
    Control.Arrow.Transformer.Writer

hidden-modules:       Control.Arrow.Internals
import-dirs:          /usr/lib/ghc-9.6.6/site-local/arrows-0.4.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/arrows-0.4.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/arrows-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arrows
hs-libraries:         HSarrows-0.4.4.2-J5DN5SZKXaXIf3BUZgn1I0
depends:              Stream-0.4.7.2-CgVp94nDICQ8fQ49WkUND3 base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-arrows/html/arrows.haddock
haddock-html:         /usr/share/doc/haskell-arrows/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

